==> machi-auth-1.0.62.tgz: package/lib/machi-emails.js <==
﻿//Send welcome and reset password emails
var ejs = require('ejs') //engine template
var path = require('path');
var extend = require('util')._extend;

var defaultTemplates = {
    verify: {
        title: 'Confirm your account',
        view: 'verify-register.html'
    },
    welcome: {
        title: 'Thanks for signing up',
        view: 'welcome-email.html'
    },
    resetPassword: {
        title: 'Reset your Password',
        view: 'reset-password-email.html'
    },
    passwordChanged: {
        title: 'Your password has been changed',
        view: 'password-changed-email.html'
    },
    changeEmail: {
        title: 'Change Email',
        view: 'email-token.html'
    },
    confirmEmail: {
        title: 'Confirm Email',
        view: 'confirm-email.html'
    }
}

var MachiEmails = module.exports.MachiEmails = function (app) {
    this.init(app);
}

MachiEmails.prototype = {
    /**
     * Initlize the Emails instance
     * @method 
     * @param app: The express app
     * @returns {{}}
     */
    init: function (app) {
        var instance = this;
        instance.machiModule = app.get('machiModule');
        var options = instance.machiModule.options;
        var emailsOptions = options.emails || {};
        instance.app = app;

        instance.emailTemplateFolder = emailsOptions.templatesFolder || path.join(__dirname, 'templates');
        instance.templates = extend(defaultTemplates, emailsOptions.templates);

        instance.fromEmail = emailsOptions.fromEmail || "no-reply@machi.na";
        instance.fromEmailTitle = emailsOptions.fromEmailTitle || "Machina";
    },
    /**
     * Sends an email to this user
     * @method constructProfile
     * @param username The username
     * @param emailTemplate The template name
     * @param locals optional, The data passed to template
     * @param callback 
     * @returns {{}}
     */
    sendEmail: function (username, emailTemplate, locals, callback) {

        this.sendEmailTo(username, undefined, emailTemplate, locals, callback);
    },


    /**
     * Sends an email to this user
     * @method constructProfile
     * @param username The username
     * @param emailTemplate The template name
     * @param locals optional, The data passed to template
     * @param callback 
     * @returns {{}}
     */
    sendEmailTo: function (username, toEmail, emailTemplate, locals, callback) {
        var instance = this;

        var template = instance.templates[emailTemplate];
        if (!template) return callback('Email Template not found');
        if (!locals) locals = {};
        instance.machiModule.connect.getUser(username, function (err, user) {
            if (err) return callback(err);
            locals.user = user;
            locals.filename = path.join(instance.emailTemplateFolder, template.view);
            locals.cache = process.env.NODE_ENV == 'production';

            ejs.renderFile(locals.filename, locals, function (err, content) {
                if (err) return callback(err);
                instance.machiModule.sendgrid.sendEmail(instance.fromEmail, instance.fromEmailTitle, [toEmail || user.email], template.title, content, function (err) {
                    callback(err, user, content);
                });

            });

        });


    }
}

==> machi-auth-1.0.72.tgz: package/lib/machi-emails.js <==
﻿//Send welcome and reset password emails
var ejs = require('ejs') //engine template
var path = require('path');
var extend = require('util')._extend;

var defaultTemplates = {
    verify: {
        title: 'Confirm your account',
        view: 'verify-register.html'
    },
    welcome: {
        title: 'Thanks for signing up',
        view: 'welcome-email.html'
    },
    resetPassword: {
        title: 'Reset your Password',
        view: 'reset-password-email.html'
    },
    passwordChanged: {
        title: 'Your password has been changed',
        view: 'password-changed-email.html'
    },
    changeEmail: {
        title: 'Change Email',
        view: 'email-token.html'
    },
    confirmEmail: {
        title: 'Confirm Email',
        view: 'confirm-email.html'
    }
}

var MachiEmails = module.exports.MachiEmails = function (app) {
    this.init(app);
}

MachiEmails.prototype = {
    /**
     * Initlize the Emails instance
     * @method 
     * @param app: The express app
     * @returns {{}}
     */
    init: function (app) {
        var instance = this;
        instance.machiModule = app.get('machiModule');
        var options = instance.machiModule.options;
        var emailsOptions = options.emails || {};
        instance.app = app;

        instance.emailTemplateFolder = emailsOptions.templatesFolder || path.join(__dirname, 'templates');
        instance.templates = extend(defaultTemplates, emailsOptions.templates);

        instance.fromEmail = emailsOptions.fromEmail || "no-reply@equeum.com";
        instance.fromEmailTitle = emailsOptions.fromEmailTitle || "Equeum";
    },
    /**
     * Sends an email to this user
     * @method constructProfile
     * @param username The username
     * @param emailTemplate The template name
     * @param locals optional, The data passed to template
     * @param callback 
     * @returns {{}}
     */
    sendEmail: function (username, emailTemplate, locals, callback) {

        this.sendEmailTo(username, undefined, emailTemplate, locals, callback);
    },


    /**
     * Sends an email to this user
     * @method constructProfile
     * @param username The username
     * @param emailTemplate The template name
     * @param locals optional, The data passed to template
     * @param callback 
     * @returns {{}}
     */
    sendEmailTo: function (username, toEmail, emailTemplate, locals, callback) {
        var instance = this;

        var template = instance.templates[emailTemplate];
        if (!template) return callback('Email Template not found');
        if (!locals) locals = {};
        instance.machiModule.connect.getUser(username, function (err, user) {
            if (err) return callback(err);
            locals.user = user;
            locals.filename = path.join(instance.emailTemplateFolder, template.view);
            locals.cache = process.env.NODE_ENV == 'production';

            ejs.renderFile(locals.filename, locals, function (err, content) {
                if (err) return callback(err);
                instance.machiModule.sendgrid.sendEmail(instance.fromEmail, instance.fromEmailTitle, [toEmail || user.email], template.title, content, function (err) {
                    callback(err, user, content);
                });

            });

        });


    }
}
